==> tuia-commercial-center-api-1.1.4-syn-20200615.031723-67-sources.jar: cn/com/duiba/tuia/commercial/center/api/dto/synthesis/req/SynCompoundRespDTO.java <==
package cn.com.duiba.tuia.commercial.center.api.dto.synthesis.req;

import cn.com.duiba.tuia.commercial.center.api.dto.synthesis.SynFoodDTO;
import cn.com.duiba.tuia.commercial.center.api.dto.synthesis.SynthesisDTO.QuickBuyInfoDTO;
import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;

import java.io.Serializable;

/**
 * @author lijicong
 * @since 2020-05-29
 */
@Getter
@Setter
public class SynCompoundRespDTO implements Serializable {

    private static final long serialVersionUID = 1L;

    @ApiModelProperty(value = "是否升级")
    private Boolean upgraded = false;

    @ApiModelProperty(value = "升级宠物等级")
    private PetGradeDTO upgradedPet;

    @ApiModelProperty(value = "是否掉落礼包")
    private Boolean dropGift;

    @ApiModelProperty(value = "礼包编码")
    private String giftCode;

    @ApiModelProperty(value = "是否曝光券")
    private Boolean dropCoupon;

    @ApiModelProperty(value = "是否解锁美食图鉴")
    private Boolean isUnlockFood = false;

    @ApiModelProperty(value = "美食图鉴")
    private SynFoodDTO unlockFood;

    @ApiModelProperty(value = "可购宠物")
    private QuickBuyInfoDTO quickBuyInfo;

    @Setter
    @Getter
    public static class PetGradeDTO implements Serializable {
        private static final long serialVersionUID = 1L;

        @ApiModelProperty(value = "宠物名称")
        private String petName;

        @ApiModelProperty(value = "宠物等级")
        private Integer petGrade;

        @ApiModelProperty(value = "宠物图片")
        private String petImg;
    }

}

==> tuia-commercial-center-api-1.1.10-syn-20200630.081646-1-sources.jar: cn/com/duiba/tuia/commercial/center/api/dto/synthesis/req/SynCompoundRespDTO.java <==
package cn.com.duiba.tuia.commercial.center.api.dto.synthesis.req;

import cn.com.duiba.tuia.commercial.center.api.dto.synthesis.SynFoodDTO;
import cn.com.duiba.tuia.commercial.center.api.dto.synthesis.SynthesisDTO.QuickBuyInfoDTO;
import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;

import java.io.Serializable;

/**
 * @author lijicong
 * @since 2020-05-29
 */
@Getter
@Setter
public class SynCompoundRespDTO implements Serializable {

    private static final long serialVersionUID = 1L;

    @ApiModelProperty(value = "是否升级")
    private Boolean upgraded = false;

    @ApiModelProperty(value = "升级宠物")
    private PetGradeDTO upgradedPet;

    @ApiModelProperty(value = "是否掉落礼包")
    private Boolean dropGift;

    @ApiModelProperty(value = "礼包编码")
    private String giftCode;

    @ApiModelProperty(value = "是否曝光券")
    private Boolean dropCoupon;

    @ApiModelProperty(value = "是否解锁美食图鉴")
    private Boolean isUnlockFood = false;

    @ApiModelProperty(value = "美食图鉴")
    private SynFoodDTO unlockFood;

    @ApiModelProperty(value = "是否有红点提示")
    private Boolean hasRedTips = false;

    @ApiModelProperty(value = "图鉴翻倍奖励编码")
    private String rewardId;

    @ApiModelProperty(value = "可购宠物")
    private QuickBuyInfoDTO quickBuyInfo;

    @Setter
    @Getter
    public static class PetGradeDTO implements Serializable {
        private static final long serialVersionUID = 1L;

        @ApiModelProperty(value = "宠物名称")
        private String petName;

        @ApiModelProperty(value = "宠物等级")
        private Integer petGrade;

        @ApiModelProperty(value = "宠物图片")
        private String petImg;
    }

}
